@@ -1,5 +1,4 @@
-#' @export
-methods_overwrite <- function() {
+methods_overwrite_impl <- function() {
   vctrs::s3_register("dplyr::add_count", "data.frame", add_count.duckplyr_df)
   vctrs::s3_register("dplyr::anti_join", "data.frame", anti_join.duckplyr_df)
   vctrs::s3_register("dplyr::arrange", "data.frame", arrange.duckplyr_df)
@@ -12,11 +11,22 @@ methods_overwrite <- function() {
   vctrs::s3_register("dplyr::do", "data.frame", do.duckplyr_df)
   vctrs::s3_register("dplyr::filter", "data.frame", filter.duckplyr_df)
   vctrs::s3_register("dplyr::full_join", "data.frame", full_join.duckplyr_df)
+  vctrs::s3_register("dplyr::group_by", "data.frame", group_by.duckplyr_df)
+  vctrs::s3_register("dplyr::group_indices", "data.frame", group_indices.duckplyr_df)
+  vctrs::s3_register("dplyr::group_keys", "data.frame", group_keys.duckplyr_df)
+  vctrs::s3_register("dplyr::group_map", "data.frame", group_map.duckplyr_df)
+  vctrs::s3_register("dplyr::group_modify", "data.frame", group_modify.duckplyr_df)
+  vctrs::s3_register("dplyr::group_nest", "data.frame", group_nest.duckplyr_df)
+  vctrs::s3_register("dplyr::group_size", "data.frame", group_size.duckplyr_df)
+  vctrs::s3_register("dplyr::group_split", "data.frame", group_split.duckplyr_df)
+  vctrs::s3_register("dplyr::group_trim", "data.frame", group_trim.duckplyr_df)
   vctrs::s3_register("dplyr::group_vars", "data.frame", group_vars.duckplyr_df)
+  vctrs::s3_register("dplyr::groups", "data.frame", groups.duckplyr_df)
   vctrs::s3_register("dplyr::inner_join", "data.frame", inner_join.duckplyr_df)
   vctrs::s3_register("dplyr::intersect", "data.frame", intersect.duckplyr_df)
   vctrs::s3_register("dplyr::left_join", "data.frame", left_join.duckplyr_df)
   vctrs::s3_register("dplyr::mutate", "data.frame", mutate.duckplyr_df)
+  vctrs::s3_register("dplyr::n_groups", "data.frame", n_groups.duckplyr_df)
   vctrs::s3_register("dplyr::nest_by", "data.frame", nest_by.duckplyr_df)
   vctrs::s3_register("dplyr::nest_join", "data.frame", nest_join.duckplyr_df)
   vctrs::s3_register("dplyr::pull", "data.frame", pull.duckplyr_df)
@@ -31,6 +41,7 @@ methods_overwrite <- function() {
   vctrs::s3_register("dplyr::rows_patch", "data.frame", rows_patch.duckplyr_df)
   vctrs::s3_register("dplyr::rows_update", "data.frame", rows_update.duckplyr_df)
   vctrs::s3_register("dplyr::rows_upsert", "data.frame", rows_upsert.duckplyr_df)
+  vctrs::s3_register("dplyr::rowwise", "data.frame", rowwise.duckplyr_df)
   vctrs::s3_register("dplyr::select", "data.frame", select.duckplyr_df)
   vctrs::s3_register("dplyr::semi_join", "data.frame", semi_join.duckplyr_df)
   vctrs::s3_register("dplyr::setdiff", "data.frame", setdiff.duckplyr_df)
