@@ -14,7 +14,7 @@ test_that("filter handles passing ...", {
   res <- g()
   expect_equal(res$x, 3L)
 
-  df <- group_by(df, x)
+  df <- duckplyr_group_by(df, x)
   res <- g()
   expect_equal(res$x, 3L)
 })
@@ -23,7 +23,7 @@ test_that("filter handles simple symbols", {
   df <- data.frame(x = 1:4, test = rep(c(T, F), each = 2))
   res <- duckplyr_filter(df, test)
 
-  gdf <- group_by(df, x)
+  gdf <- duckplyr_group_by(df, x)
   res <- duckplyr_filter(gdf, test)
 
   h <- function(data) {
@@ -51,7 +51,7 @@ test_that("filter handles simple symbols", {
 
 test_that("filter handlers scalar results", {
   expect_equal(duckplyr_filter(mtcars, min(mpg) > 0), mtcars, ignore_attr = TRUE)
-  expect_equal(duckplyr_filter(group_by(mtcars, cyl), min(mpg) > 0), group_by(mtcars, cyl))
+  expect_equal(duckplyr_filter(duckplyr_group_by(mtcars, cyl), min(mpg) > 0), duckplyr_group_by(mtcars, cyl))
 })
 
 test_that("filter propagates attributes", {
@@ -116,7 +116,7 @@ test_that("$ does not end call traversing. #502", {
 
   # Do some aggregation
   trial_outcomes <- d %>%
-    group_by(Subject, TrialNo) %>%
+    duckplyr_group_by(Subject, TrialNo) %>%
     duckplyr_summarise(MeanOutcome = mean(Outcome), .groups = "drop")
 
   left <- duckplyr_filter(trial_outcomes, MeanOutcome < analysis_opts$min_outcome)
@@ -155,7 +155,7 @@ test_that("%in% works as expected (#126)", {
   res <- df %>% duckplyr_filter(a %in% letters)
   expect_equal(nrow(res), 2L)
 
-  res <- df %>% group_by(g) %>% duckplyr_filter(a %in% letters)
+  res <- df %>% duckplyr_group_by(g) %>% duckplyr_filter(a %in% letters)
   expect_equal(nrow(res), 2L)
 })
 
@@ -182,7 +182,7 @@ test_that("filter does not alter expression (#971)", {
 
 test_that("hybrid evaluation handles $ correctly (#1134)", {
   df <- tibble(x = 1:10, g = rep(1:5, 2))
-  res <- df %>% group_by(g) %>% duckplyr_filter(x > min(df$x))
+  res <- df %>% duckplyr_group_by(g) %>% duckplyr_filter(x > min(df$x))
   expect_equal(nrow(res), 9L)
 })
 
@@ -220,28 +220,28 @@ test_that("filter, slice and arrange preserves attributes (#1064)", {
 
 test_that("filter works with rowwise data (#1099)", {
   df <- tibble(First = c("string1", "string2"), Second = c("Sentence with string1", "something"))
-  res <- df %>% rowwise() %>% duckplyr_filter(grepl(First, Second, fixed = TRUE))
+  res <- df %>% duckplyr_rowwise() %>% duckplyr_filter(grepl(First, Second, fixed = TRUE))
   expect_equal(nrow(res), 1L)
   expect_equal(df[1, ], duckplyr_ungroup(res))
 })
 
 test_that("grouped filter handles indices (#880)", {
-  res <- iris %>% group_by(Species) %>% duckplyr_filter(Sepal.Length > 5)
+  res <- iris %>% duckplyr_group_by(Species) %>% duckplyr_filter(Sepal.Length > 5)
   res2 <- duckplyr_mutate(res, Petal = Petal.Width * Petal.Length)
   expect_equal(nrow(res), nrow(res2))
   expect_equal(group_rows(res), group_rows(res2))
-  expect_equal(group_keys(res), group_keys(res2))
+  expect_equal(duckplyr_group_keys(res), duckplyr_group_keys(res2))
 })
 
 test_that("duckplyr_filter(FALSE) handles indices", {
   out <- mtcars %>%
-    group_by(cyl) %>%
+    duckplyr_group_by(cyl) %>%
     duckplyr_filter(FALSE, .preserve = TRUE) %>%
     group_rows()
   expect_identical(out, list_of(integer(), integer(), integer(), .ptype = integer()))
 
   out <- mtcars %>%
-    group_by(cyl) %>%
+    duckplyr_group_by(cyl) %>%
     duckplyr_filter(FALSE, .preserve = FALSE) %>%
     group_rows()
   expect_identical(out, list_of(.ptype = integer()))
@@ -301,7 +301,7 @@ test_that("filter handles list columns", {
   expect_equal(res, list(1:10))
 
   res <- tibble(a=1:2, x = list(1:10, 1:5)) %>%
-    group_by(a) %>%
+    duckplyr_group_by(a) %>%
     duckplyr_filter(a == 1) %>%
     duckplyr_pull(x)
   expect_equal(res, list(1:10))
@@ -317,19 +317,19 @@ test_that("hybrid function row_number does not trigger warning in filter (#3750)
 test_that("duckplyr_filter() preserve order across groups (#3989)", {
   df <- tibble(g = c(1, 2, 1, 2, 1), time = 5:1, x = 5:1)
   res1 <- df %>%
-    group_by(g) %>%
+    duckplyr_group_by(g) %>%
     duckplyr_filter(x <= 4) %>%
     duckplyr_arrange(time)
 
   res2 <- df %>%
-    group_by(g) %>%
+    duckplyr_group_by(g) %>%
     duckplyr_arrange(time) %>%
     duckplyr_filter(x <= 4)
 
   res3 <- df %>%
     duckplyr_filter(x <= 4) %>%
     duckplyr_arrange(time) %>%
-    group_by(g)
+    duckplyr_group_by(g)
 
   expect_equal(res1, res2)
   expect_equal(res1, res3)
@@ -357,17 +357,17 @@ test_that("duckplyr_filter() handles matrix and data frame columns (#3630)", {
   expect_equal(duckplyr_filter(df, y[,1] == 1), df[1, ])
   expect_equal(duckplyr_filter(df, z$A == 1), df[1, ])
 
-  gdf <- group_by(df, x)
+  gdf <- duckplyr_group_by(df, x)
   expect_equal(duckplyr_filter(gdf, x == 1), gdf[1, ])
   expect_equal(duckplyr_filter(gdf, y[,1] == 1), gdf[1, ])
   expect_equal(duckplyr_filter(gdf, z$A == 1), gdf[1, ])
 
-  gdf <- group_by(df, y)
+  gdf <- duckplyr_group_by(df, y)
   expect_equal(duckplyr_filter(gdf, x == 1), gdf[1, ])
   expect_equal(duckplyr_filter(gdf, y[,1] == 1), gdf[1, ])
   expect_equal(duckplyr_filter(gdf, z$A == 1), gdf[1, ])
 
-  gdf <- group_by(df, z)
+  gdf <- duckplyr_group_by(df, z)
   expect_equal(duckplyr_filter(gdf, x == 1), gdf[1, ])
   expect_equal(duckplyr_filter(gdf, y[,1] == 1), gdf[1, ])
   expect_equal(duckplyr_filter(gdf, z$A == 1), gdf[1, ])
@@ -408,11 +408,11 @@ test_that("duckplyr_filter() allows matrices with 1 column with a deprecation wa
 
   # Only warns once when grouped
   df <- tibble(x = c(1, 1, 2, 2))
-  gdf <- group_by(df, x)
+  gdf <- duckplyr_group_by(df, x)
   expect_snapshot({
     out <- duckplyr_filter(gdf, matrix(c(TRUE, FALSE), nrow = 2))
   })
-  expect_identical(out, group_by(tibble(x = c(1, 2)), x))
+  expect_identical(out, duckplyr_group_by(tibble(x = c(1, 2)), x))
 })
 
 test_that("duckplyr_filter() disallows matrices with >1 column", {
@@ -438,7 +438,7 @@ test_that("duckplyr_filter() gives useful error messages", {
     # wrong type
     (expect_error(
       iris %>%
-        group_by(Species) %>%
+        duckplyr_group_by(Species) %>%
         duckplyr_filter(1:n())
     ))
     (expect_error(
@@ -454,12 +454,12 @@ test_that("duckplyr_filter() gives useful error messages", {
     # wrong size
     (expect_error(
       iris %>%
-        group_by(Species) %>%
+        duckplyr_group_by(Species) %>%
         duckplyr_filter(c(TRUE, FALSE))
     ))
     (expect_error(
                     iris %>%
-                      rowwise(Species) %>%
+                      duckplyr_rowwise(Species) %>%
                       duckplyr_filter(c(TRUE, FALSE))
     ))
     (expect_error(
@@ -470,12 +470,12 @@ test_that("duckplyr_filter() gives useful error messages", {
     # wrong size in column
     (expect_error(
                     iris %>%
-                      group_by(Species) %>%
+                      duckplyr_group_by(Species) %>%
                       duckplyr_filter(data.frame(c(TRUE, FALSE)))
     ))
     (expect_error(
                     iris %>%
-                      rowwise() %>%
+                      duckplyr_rowwise() %>%
                       duckplyr_filter(data.frame(c(TRUE, FALSE)))
     ))
     (expect_error(
@@ -490,7 +490,7 @@ test_that("duckplyr_filter() gives useful error messages", {
     # wrong type in column
     (expect_error(
                     iris %>%
-                      group_by(Species) %>%
+                      duckplyr_group_by(Species) %>%
                       duckplyr_filter(data.frame(Sepal.Length > 3, 1:n()))
     ))
     (expect_error(
@@ -504,7 +504,7 @@ test_that("duckplyr_filter() gives useful error messages", {
     ))
     (expect_error(
                     mtcars %>%
-                      group_by(cyl) %>%
+                      duckplyr_group_by(cyl) %>%
                       duckplyr_filter(`_x`)
     ))
 
@@ -539,7 +539,7 @@ test_that("duckplyr_filter() gives useful error messages", {
 })
 
 test_that("filter preserves grouping", {
-  gf <- group_by(tibble(g = c(1, 1, 1, 2, 2), x = 1:5), g)
+  gf <- duckplyr_group_by(tibble(g = c(1, 1, 1, 2, 2), x = 1:5), g)
 
   i <- count_regroups(out <- duckplyr_filter(gf, x %in% c(3,4)))
   expect_equal(i, 0L)
@@ -616,9 +616,9 @@ test_that("filter keeps zero length groups", {
     g = c(1, 1, 2, 2),
     x = c(1, 2, 1, 4)
   )
-  df <- group_by(df, e, f, g, .drop = FALSE)
+  df <- duckplyr_group_by(df, e, f, g, .drop = FALSE)
 
-  expect_equal(group_size(duckplyr_filter(df, f == 1)), c(2, 0, 0) )
+  expect_equal(duckplyr_group_size(duckplyr_filter(df, f == 1)), c(2, 0, 0) )
 })
 
 test_that("filtering retains labels for zero length groups", {
@@ -628,7 +628,7 @@ test_that("filtering retains labels for zero length groups", {
     g = c(1, 1, 2, 2),
     x = c(1, 2, 1, 4)
   )
-  df <- group_by(df, e, f, g, .drop = FALSE)
+  df <- duckplyr_group_by(df, e, f, g, .drop = FALSE)
 
   expect_equal(
     duckplyr_ungroup(duckplyr_count(duckplyr_filter(df, f == 1))),
@@ -699,7 +699,7 @@ test_that("can't use `.by` with `.preserve`", {
 
 test_that("catches `.by` with grouped-df", {
   df <- tibble(x = 1)
-  gdf <- group_by(df, x)
+  gdf <- duckplyr_group_by(df, x)
 
   expect_snapshot(error = TRUE, {
     duckplyr_filter(gdf, .by = x)
@@ -708,7 +708,7 @@ test_that("catches `.by` with grouped-df", {
 
 test_that("catches `.by` with rowwise-df", {
   df <- tibble(x = 1)
-  rdf <- rowwise(df)
+  rdf <- duckplyr_rowwise(df)
 
   expect_snapshot(error = TRUE, {
     duckplyr_filter(rdf, .by = x)
